#############################
 Hyperparameter Optimization
#############################

************
 Algorithms
************

.. currentmodule:: aiaccel.hpo.algorithms

.. autosummary::
    :toctree: generated/

    NelderMeadAlgorism

******************
 Optuna Utilities
******************

Samplers
========

.. currentmodule:: aiaccel.hpo.optuna.samplers

.. autosummary::
    :toctree: generated/

    NelderMeadSampler

Hparam
======

.. currentmodule:: aiaccel.hpo.optuna.hparams

.. autosummary::
    :toctree: generated/

    Hparam
    Const
    Float
    Int
    Categorical
